import { $get, $post, $del, $patch, $put } from "@/plugins/axios";

// login
export const login = datas => {
  return $post("/api/login", datas);
};
export const logout = () => {
  return $del("/api/logout");
};
export const resetPwd = ({ userId, password }) => {
  return $patch(`/api/${userId}/password`, { password }, "json");
};

// work-manage
export const workList = () => {
  return $get("/api/admin/works");
};
export const workDetail = workId => {
  return $get(`/api/admin/works/${workId}`);
};
export const updateWork = datas => {
  return $put(`/api/admin/works/${datas.id}`, datas, "json");
};
export const createWork = datas => {
  return $post("/api/admin/works", datas, "json");
};
export const activeWork = workId => {
  return $patch(`/api/admin/works/${workId}`, {});
};
export const deleteWork = workId => {
  return $del(`/api/admin/works/${workId}`);
};

// work-overview
export const workOverviewDetail = workId => {
  return $get(`/api/admin/works/${workId}/overview`);
};

// paper-manage
export const paperPageList = datas => {
  return $get("/api/papers/listByQuestion", datas);
};
export const rotatePaper = (imageId, degree) => {
  return $get(`/api/images/${imageId}/rotate`, { degree });
};
export const absentPaper = imageId => {
  return $post(`/api/score/missing/${imageId}`, {});
};
export const markPaper = ({ paperId, isMark }) => {
  return $post(`/api/papers/mark_paper`, { paperId, isMark });
};

// client-monitor
export const clientMonitorList = datas => {
  return $get("/api/marklog/equipmentMonitor", datas);
};

// student-manage
export const studentPageList = datas => {
  return $get("/api/students", datas);
};
export const updateStudent = datas => {
  if (datas.id) {
    return $put(`/api/students/${datas.id}`, datas, "json");
  } else {
    return $post(`/api/students`, datas, "json");
  }
};
export const deleteStudent = studentId => {
  return $del(`/api/students/${studentId}`, {});
};
export const areaSchoolRoomCascadeList = workId => {
  // 考区-学校-考场 联动查询
  return $get(`/api/students/select/${workId}`);
};

// client-set -------------------------->
// client-user-set
export const clientUserPageList = datas => {
  return $get("/api/admin/users/collect", datas);
};
export const clientUserQuery = workId => {
  return $get("/api/admin/users/collect/all", { workId });
};
export const updateClientUser = datas => {
  if (datas.id) {
    return $put(`/api/admin/users/collect/${datas.id}`, datas, "json");
  } else {
    return $post("/api/admin/users/collect", datas, "json");
  }
};
export const deleteClientUser = userId => {
  return $del(`/api/admin/users/collect/${userId}`, {});
};
// inspection-user-set
export const inspectionUserPageList = () => {
  return $get("/api/admin/users/inspection");
};
export const deleteInspectionUser = userId => {
  return $del(`/api/admin/users/collect/${userId}`, {});
};
// client-param-set -------------------------->
// subject-set
export const subjectList = workId => {
  return $get(`/api/marksubjects/${workId}/subjects`);
};
export const subjectDetail = subjectId => {
  return $get(`/api/marksubjects/${subjectId}`);
};
export const updateSubject = datas => {
  if (datas.id) {
    return $post(`/api/marksubjects/${datas.id}/updateName`, datas);
  } else {
    return $post(`/api/marksubjects/${datas.id}`, datas);
  }
};
export const enableSubject = subjectId => {
  return $post(`/api/marksubjects/${subjectId}/updateEnable`, {});
};
// param-set
export const getParamsSet = async workId => {
  const data = await $get("/api/param/getParam", { workId });
  let result = {};
  const keys = [
    "collectConfig",
    "levelConfig",
    "roughLevelConfig",
    "scoreConfig"
  ];
  keys.forEach(key => {
    result[key] = data[key] ? JSON.parse(data[key]) : {};
  });
  return result;
};
export const updateCollectParams = datas => {
  return $post("/api/param/collect", datas, "json");
};

// grading-set -------------------------->
// grading-level-set
// TO workDetail and updateWork

// grading-rule-set
export const updateLevelParams = datas => {
  return $post("/api/param/level", datas, "json");
};
export const updateRoughLevelParams = datas => {
  return $post("/api/param/rough_level", datas, "json");
};
// update-paper
// grading-rule-set

// mark-set -------------------------->
// mark-rule-set
export const updateScoreParams = datas => {
  return $post("/api/param/score", datas, "json");
};
// export-paper
export const exportScorePictures = datas => {
  return $get("/api/file/image/exportScorePictures", datas);
};
export const exportDecryptPictures = datas => {
  return $get("/api/file/image/exportDecryptPictures", datas);
};

// quality-analysis -------------------------->
// 档位占比
export const levelsPropReport = datas => {
  return $get("/api/quality/levelsPropReport", datas);
};
// 累计偏差（差值和）
export const deviationReport = datas => {
  return $get("/api/quality/deviationReport", datas);
};
// 累计误差（差值绝对值之和）
export const distanceReport = datas => {
  return $get("/api/quality/distanceReport", datas);
};
// 打回次数
export const callbackReport = datas => {
  return $get("/api/quality/callbackReport", datas);
};

// student-score -------------------------->
export const studentScoreList = datas => {
  return $get(`/api/papers/studentScore`, datas);
};
// exam-paper-view
export const uploadPaperList = workId => {
  return $get(`/api/papers/${workId}/listUploadPaper`);
};

// check-data
export const checkDataList = workId => {
  return $get(`/api/check_data/list`, { workId });
};
export const dataItemCheck = ({ workId, checkItem, paramValue }) => {
  return $post(`/api/check_data/check`, { workId, checkItem, paramValue });
};
// grading -------------------------->
// grading-user-manage
export const gradingUserList = datas => {
  return $get("/api/admin/users", datas);
};
export const updateGradingUser = datas => {
  if (datas.id) {
    return $put(`/api/admin/users/${datas.id}`, datas, "json");
  } else {
    return $post("/api/admin/users", datas, "json");
  }
};
export const deleteGradingUser = userId => {
  return $del(`/api/admin/users/${userId}`);
};
// grading-group-manage
export const gradingGroupList = subjectId => {
  return $get(`/api/marksubjects/${subjectId}/markergroups`, {});
};
export const updateGradingGroup = (subjectId, datas) => {
  if (datas.groupId) {
    return $patch(
      `/api/marksubjects/${subjectId}/markergroups/${datas.groupId}`,
      datas,
      "json"
    );
  } else {
    return $post(`/api/marksubjects/${subjectId}/markergroups`, datas, "json");
  }
};
export const deleteGradingGroup = (subjectId, groupId) => {
  return $del(`/api/marksubjects/${subjectId}/markergroups/${groupId}`);
};
export const deleteGradeGroupStudent = (subject, groupId) => {
  return $del(`/api/marksubjects/marker_groups_student/${subject}/${groupId}`);
};
export const markUserList = ({ workId, subjectId }) => {
  return $get("/api/markers", { workId, subject: subjectId });
};
export const userGroupList = ({ workId, subject }) => {
  // workId=&subject=&stage=  stage非必填
  return $get("/api/admin/users/list_group", { workId, subject });
};
export const leaderMarkUserList = datas => {
  // workId=&subject=&stage=&markerId=
  return $get("/api/admin/users/list_group_users", datas);
};
// grading-progress
export const gradingProgressDetail = ({ workId, subject }) => {
  return $get("/api/markers/stat/progress", { workId, subject });
};
export const markLeaderGradingProgressDetail = ({ workId, subject }) => {
  return $get("/api/markers/mark_leader/stat/progress", { workId, subject });
};
export const areaStatProgress = subjectId => {
  return $get(`/api/marksubjects/${subjectId}/areaProgress`);
};
export const createTryGradingTask = datas => {
  // workId, subject
  return $get(`/api/trial/startTrial`, datas);
};
export const finishTryGradingTask = datas => {
  // workId, subject
  return $get(`/api/trial/finishTrial`, datas);
};
export const cleanGradingData = datas => {
  // workId, subject,stage,,loginName,password
  return $post(`/api/markers/subject/reset`, datas);
};
// grade-task
export const checkMissionStatus = ({ workId, subject }) => {
  return $get("/api/trial/checkMissionStatus", { workId, subject });
};
export const checkCanPublishTask = subjectId => {
  return $get(`/api/marksubjects/${subjectId}/canLevel`);
};
// 分档任务发布
export const createGradingTask = ({ subjectId, taskCount, questionId }) => {
  return $patch(
    `/api/marksubjects/${subjectId}`,
    {
      taskCount,
      questionId
    },
    "json"
  );
};
// 进入打分阶段，和上面掉的同一个接口，分开是为了便于区分
export const gotoNextStage = ({ workId, subject }) => {
  return $post(`/api/marksubjects/go_next_stage`, { workId, subject });
};
// 打分任务发布
export const publishScoreTask = ({ subjectId, questionId, taskList }) => {
  return $post(
    `/api/marksubjects/${subjectId}/publishScore`,
    {
      questionId,
      taskList
    },
    "json"
  );
};
// grading-standard-paper-manage
export const cancelStandardPaper = paperIds => {
  return $patch(`/api/papers/batch/cancelSample`, { paperIds }, "json");
};

// grading-detail ------------------------->
// grading-analysis
export const gradingStatData = datas => {
  return $get("/api/marktasks/levelStatDetail", datas);
};

// level relate
export const workLevelList = async (workId, stage = "LEVEL") => {
  const data = await $get(`/api/admin/works/${workId}/levels`);
  if (stage === "ROUGH_LEVEL") {
    const levelMap = {};
    data.forEach(item => {
      const ind = item.roughCode;
      if (!levelMap[ind]) levelMap[ind] = [];
      levelMap[ind].push(item);
    });
    let levelList = Object.keys(levelMap).map((roughCode, ind) => {
      const group = levelMap[roughCode];
      const levels = group.map(item => item.code);

      return {
        id: ind + 1,
        name: roughCode,
        minScore: levels[0],
        maxScore: levels.slice(-1)[0]
      };
    });
    levelList.sort((a, b) => (a.name < b.name ? -1 : 1));
    return levelList;
  } else {
    return data.map(item => {
      return {
        ...item,
        name: item.code
      };
    });
  }
};
export const levelStatData = (subjectId, questionId) => {
  return $get(`/api/marksubjects/${subjectId}/stat/levels`, { questionId });
};
export const scoreStatData = (subjectId, questionId) => {
  return $get(`/api/marksubjects/${subjectId}/stat/scores`, { questionId });
};
export const markLeaderLevelStatData = (
  subjectId,
  questionId,
  stage = "LEVEL"
) => {
  if (stage === "LEVEL") {
    return $get(`/api/marksubjects/${subjectId}/mark_leader/stat/levels`, {
      questionId
    });
  } else {
    return $get(`/api/marksubjects/${subjectId}/mark_leader/stat/roughLevels`, {
      questionId
    });
  }
};
export const markLeaderScoreStatData = (subjectId, questionId) => {
  return $get(`/api/marksubjects/${subjectId}/mark_leader/stat/scores`, {
    questionId
  });
};
export const markerLevelStatData = (userId, questionId) => {
  return $get(`/api/markers/${userId}/stat/levels`, { questionId });
};
export const markerLevelTotalStatData = (
  userId,
  questionId,
  stage = "LEVEL"
) => {
  if (stage === "LEVEL") {
    return $get(`/api/markers/${userId}/stat/totalLevels`, { questionId });
  } else {
    return $get(`/api/markers/${userId}/stat/totalRoughLevels`, { questionId });
  }
};

// area
export const areaList = ({ workId, subject }) => {
  return $get("/api/questions", { workId, subject });
};
export const sampleAreaList = ({ workId, subject }) => {
  return $get("/api/questions/sampleQuestions", { workId, subject });
};
// papers
export const paperList = datas => {
  // ?questionId=64&level=A&page=0&size=6&sort=secretNumber&isSample=true
  return $get("/api/papers", datas);
};
export const markerTaskList = datas => {
  // ?stage=LEVEL&markerId=49&size=6&page=0&sort=updatedOn,desc&questionId=73&isSample=false&level=C
  return $get("/api/marktasks", datas);
};
export const markTaskPaperList = datas => {
  // ?workId=&stage=&subject=&markerId=
  return $get("/api/marktasks/list_mark_task", datas);
};
// grading or scoring
export const paperSelectLevelOrScore = (taskId, result, stage) => {
  // stage => LEVEL or SCORE
  return $patch(`/api/marktasks/${taskId}`, { stage, result }, "json");
};
export const paperSelectLevelBatch = (taskIds, result, stage) => {
  return $patch(`/api/marktasks/batch`, { taskIds, result, stage }, "json");
};
export const paperTaskPass = (stage, taskId) => {
  return $post(`/api/marktasks/${stage}/${taskId}/skip`, {});
};
export const markTask = ({ markTaskId, stage, isMark }) => {
  return $post(`/api/marktasks/${stage}/mark_task`, { markTaskId, isMark });
};
// grade or mark history
export const markHistoryList = (paperId, stage) => {
  return $get(`/api/papers/${paperId}/marktasks`, { stage });
};
// marker-status-info
export const markerDetail = userId => {
  return $get(`/api/markers/${userId}`);
};
// leader mark paper
export const leaderGradingPaper = datas => {
  // datas:{value: ,level:,range?, paperIds: '1,2'}
  return $patch(`/api/papers/batch`, datas, "json");
  // return $patch(`/api/papers/${paperId}`, datas, "json");
};
// review action history
export const actionHistory = datas => {
  return $get("/api/marktasks/reviewPaper", datas);
};
export const actionLeaderHistory = datas => {
  return $get("/api/marktasks/kzzReviewPaper", datas);
};
// sn search
export const taskSnSearch = (type, code, questionId, stage) => {
  if (type === "task") {
    return $get(`/api/papers/search/byTaskSecretNumber`, {
      sn: code,
      questionId,
      stage
    });
  } else {
    const paramName = type === "examNumber" ? "examNumber" : "sn";
    return $get(`/api/papers/one`, { [paramName]: code, questionId, stage });
  }
};
// mark step change level
export const markStepChangeLevel = ({ subjectId, paperId, level, userId }) => {
  // paperId,level
  return $post(`/api/changelevel/${subjectId}/changeLevel`, {
    paperId,
    level,
    userId
  });
};
export const changeLevelPaperList = datas => {
  // 纪检人员、超级管理员和科组长查询改档列表
  // status => 0:未审核,1:已审核
  // 科组长默认查询审核通过的
  return $get("/api/changelevel/list", datas);
};

// mark -------------------------->
// mark-progress
// to see grading progress

// mark-task-manage
export const checkMarkTaskSubmitType = subjectId => {
  return $get(`/api/marksubjects/${subjectId}/canScoreAll`);
};
export const checkMarkTaskCanSubmit = (subjectId, questionId) => {
  let datas = questionId ? { questionId } : null;
  return $get(`/api/marksubjects/${subjectId}/canScore`, datas);
};
export const markTaskInfo = (subjectId, questionId) => {
  let datas = questionId ? { questionId } : null;
  return $get(`/api/marksubjects/${subjectId}/scoreProgress`, datas);
};
// mark-detail
export const markerScoreStatData = (userId, questionId) => {
  return $get(`/api/markers/${userId}/stat/scores`, { questionId });
};
export const markerScoreTotalStatData = (userId, questionId) => {
  return $get(`/api/markers/${userId}/stat/totalScores`, { questionId });
};
// mark-operation
export const markerChangeLevelPaperList = datas => {
  // ?markerId=49&size=6&page=0&isShift=true&isShiftScore=false&questionId=10
  return $get(`/api/marktasks/shift`, datas);
};

// inspection -------------------------->
// inspection-log
export const inspectionActionLogPageList = datas => {
  return $get(`/api/marklog/selectMarkLog`, datas);
};
export const inspectionCollectLogPageList = datas => {
  return $get(`/api/marklog/selectCollectMarkLog`, datas);
};
export const inspectionConfirmCheckGrade = datas => {
  // id,auditStatus
  return $post(`/api/changelevel/changeLevelAudit`, datas);
};
export const logTypeList = () => {
  return $get(`/api/marklog/listTypes`);
};

// notice -------------------------->
export const userSendNoticeList = datas => {
  // subject=&stage=&sendUserId=
  return $get(`/api/message/page_send`, datas);
};
export const userReceiveNoticeList = datas => {
  // subject=&stage=&receiveUserId=&lastId=
  return $get(`/api/message/page_receive`, datas);
};
export const fetchReleaseUnreadNotice = datas => {
  // subject=&stage=&receiveUserId=
  return $get(`/api/message/list_receive_unread`, datas);
};
export const readNotice = ids => {
  return $post(`/api/message/read`, { ids }, "json");
};
export const sendNotice = datas => {
  return $post(`/api/message/send`, datas, "json");
};
